@@ -1,36 +1,42 @@
 ## this is the "cell getter" for range_read_cells() and read_sheet()
-get_cells <- function(ss,
-                      sheet = NULL,
-                      range = NULL,
-                      col_names_in_sheet = TRUE,
-                      skip = 0, n_max = Inf,
-                      detail_level = c("default", "full"),
-                      discard_empty = TRUE) {
+get_cells <- function(
+  ss,
+  sheet = NULL,
+  range = NULL,
+  col_names_in_sheet = TRUE,
+  skip = 0,
+  n_max = Inf,
+  detail_level = c("default", "full"),
+  discard_empty = TRUE,
+  call = caller_env()
+) {
   ssid <- as_sheets_id(ss)
 
-  maybe_sheet(sheet)
-  check_range(range)
-  check_bool(col_names_in_sheet)
-  check_non_negative_integer(skip)
-  check_non_negative_integer(n_max)
+  maybe_sheet(sheet, call = call)
+  check_range(range, call = call)
+  check_bool(col_names_in_sheet, call = call)
+  check_non_negative_integer(skip, call = call)
+  check_non_negative_integer(n_max, call = call)
   detail_level <- match.arg(detail_level)
-  check_bool(discard_empty)
+  check_bool(discard_empty, call = call)
 
   ## retrieve spreadsheet metadata --------------------------------------------
   x <- gs4_get(ssid)
-  message_glue("Reading from {dq(x$name)}")
+  gs4_bullets(c(v = "Reading from {.s_sheet {x$name}}."))
 
   ## prepare range specification for API --------------------------------------
 
   ## user's range, sheet, skip --> qualified A1 range, suitable for API
   range_spec <- as_range_spec(
     range,
-    sheet = sheet, skip = skip,
-    sheets_df = x$sheets, nr_df = x$named_ranges
+    sheet = sheet,
+    skip = skip,
+    sheets_df = x$sheets,
+    nr_df = x$named_ranges
   )
   # if we send no range, we get all cells from all sheets; not what we want
   effective_range <- as_A1_range(range_spec) %||% first_visible_name(x$sheets)
-  message_glue("Range {dq(effective_range)}")
+  gs4_bullets(c(v = "Range {.range {effective_range}}."))
 
   ## main GET -----------------------------------------------------------------
   resp <- read_cells_impl_(
@@ -68,10 +74,12 @@ get_cells <- function(ss,
 # I want a separate worker so there is a version of this available that
 # accepts `fields` (or `includeGridData`), yet I don't want a user-facing
 # function that exposes those details
-read_cells_impl_ <- function(ssid,
-                             ranges,
-                             fields = NULL,
-                             detail_level = c("default", "full")) {
+read_cells_impl_ <- function(
+  ssid,
+  ranges,
+  fields = NULL,
+  detail_level = c("default", "full")
+) {
   # there are 2 ways to control the level of detail re: cell data:
   #   1. Supply a field mask. What we currently do.
   #   2. Set `includeGridData` to true. This gets *everything* about the
@@ -83,7 +91,8 @@ read_cells_impl_ <- function(ssid,
     "full" = ""
   )
   default_fields <- c(
-    "spreadsheetId", "properties.title",
+    "spreadsheetId",
+    "properties.title",
     "sheets.properties(sheetId,title)",
     glue("sheets.data(startRow,startColumn,rowData{cell_mask})")
   )
@@ -130,7 +139,7 @@ cells <- function(x = list()) {
       seq.int(from = start_row, length.out = n_rows),
       times = row_lengths
     ),
-    col = start_column + sequence(row_lengths) - 1,
+    col = as.integer(start_column + sequence(row_lengths) - 1),
     cell = purrr::flatten(row_data)
   )
 }
@@ -145,14 +154,14 @@ insert_shims <- function(df, cell_limits) {
 
   ## 1-based indices, referring to cell coordinates in the spreadsheet
   start_row <- cell_limits$ul[[1]]
-  end_row   <- cell_limits$lr[[1]]
+  end_row <- cell_limits$lr[[1]]
   start_col <- cell_limits$ul[[2]]
-  end_col   <- cell_limits$lr[[2]]
+  end_col <- cell_limits$lr[[2]]
 
-  shim_up    <- notNA(start_row) && start_row < min(df$row)
-  shim_left  <- notNA(start_col) && start_col < min(df$col)
-  shim_down  <- notNA(end_row)   &&   end_row > max(df$row)
-  shim_right <- notNA(end_col)   &&   end_col > max(df$col)
+  shim_up <- notNA(start_row) && start_row < min(df$row)
+  shim_left <- notNA(start_col) && start_col < min(df$col)
+  shim_down <- notNA(end_row) && end_row > max(df$row)
+  shim_right <- notNA(end_col) && end_col > max(df$col)
 
   ## add placeholder to establish upper left corner
   if (shim_up || shim_left) {
