@@ -22,9 +22,9 @@ gs4_get <- function(ss) {
 
 ## I want a separate worker so there is a version of this available that
 ## accepts `fields`, yet I don't want a user-facing function with `fields` arg
-gs4_get_impl_ <- function(ssid,
-                          fields = NULL) {
-  fields <- fields %||% "spreadsheetId,properties,spreadsheetUrl,sheets.properties,sheets.protectedRanges,namedRanges"
+gs4_get_impl_ <- function(ssid, fields = NULL) {
+  fields <- fields %||%
+    "spreadsheetId,properties,spreadsheetUrl,sheets.properties,sheets.protectedRanges,namedRanges"
   req <- request_generate(
     "sheets.spreadsheets.get",
     params = list(
