@@ -10,9 +10,6 @@
 #'   throughout the googlesheets4 package.
 #'
 #' `read_sheet()` and `range_read()` are synonyms and you can use either one.
-#' The first release of googlesheets used a `sheets_` prefix everywhere, so we
-#' had `sheets_read()`. It still works, but it's deprecated and will go away
-#' rather swiftly.
 #'
 #' @section Column Specification:
 #'
@@ -75,47 +72,55 @@
 #' @return A [tibble][tibble::tibble-package]
 #' @export
 #'
-#' @examples
-#' if (gs4_has_token()) {
-#'   ss <- gs4_example("deaths")
-#'   read_sheet(ss, range = "A5:F15")
-#'   read_sheet(ss, range = "other!A5:F15", col_types = "ccilDD")
-#'   read_sheet(ss, range = "arts_data", col_types = "ccilDD")
+#' @examplesIf gs4_has_token()
+#' ss <- gs4_example("deaths")
+#' read_sheet(ss, range = "A5:F15")
+#' read_sheet(ss, range = "other!A5:F15", col_types = "ccilDD")
+#' read_sheet(ss, range = "arts_data", col_types = "ccilDD")
 #'
-#'   read_sheet(gs4_example("mini-gap"))
-#'   read_sheet(
-#'     gs4_example("mini-gap"),
-#'     sheet = "Europe",
-#'     range = "A:D",
-#'     col_types = "ccid"
-#'   )
-#' }
-range_read <- function(ss,
-                       sheet = NULL,
-                       range = NULL,
-                       col_names = TRUE, col_types = NULL,
-                       na = "", trim_ws = TRUE,
-                       skip = 0, n_max = Inf,
-                       guess_max = min(1000, n_max),
-                       .name_repair = "unique") {
-  ## check these first, so we don't download cells in vain
-  col_spec <- standardise_col_spec(col_names, col_types)
+#' read_sheet(gs4_example("mini-gap"))
+#' read_sheet(
+#'   gs4_example("mini-gap"),
+#'   sheet = "Europe",
+#'   range = "A:D",
+#'   col_types = "ccid"
+#' )
+range_read <- function(
+  ss,
+  sheet = NULL,
+  range = NULL,
+  col_names = TRUE,
+  col_types = NULL,
+  na = "",
+  trim_ws = TRUE,
+  skip = 0,
+  n_max = Inf,
+  guess_max = min(1000, n_max),
+  .name_repair = "unique"
+) {
+  # check these first, so we don't download cells in vain
+  col_spec <- standardise_col_spec(col_names, col_types, call = current_env())
   check_character(na)
   check_bool(trim_ws)
   check_non_negative_integer(guess_max)
 
-  ## range spec params are checked inside get_cells():
-  ## ss, sheet, range, skip, n_max
+  # range spec params are checked inside get_cells():
+  # ss, sheet, range, skip, n_max
   df <- get_cells(
     ss = ss,
-    sheet = sheet, range = range,
+    sheet = sheet,
+    range = range,
     col_names_in_sheet = isTRUE(col_spec$col_names),
-    skip = skip, n_max = n_max
+    skip = skip,
+    n_max = n_max
   )
 
   spread_sheet_impl_(
     df,
-    col_spec = col_spec, na = na, trim_ws = trim_ws, guess_max = guess_max,
+    col_spec = col_spec,
+    na = na,
+    trim_ws = trim_ws,
+    guess_max = guess_max,
     .name_repair = .name_repair
   )
 }
@@ -143,39 +148,49 @@ read_sheet <- range_read
 #'   whitespace trimming.
 #' @export
 #'
-#' @examples
-#' if (gs4_has_token()) {
-#'   df <- gs4_example("mini-gap") %>%
-#'     range_read_cells()
-#'   spread_sheet(df)
+#' @examplesIf gs4_has_token()
+#' df <- gs4_example("mini-gap") %>%
+#'   range_read_cells()
+#' spread_sheet(df)
 #'
-#'   # ^^ gets same result as ...
-#'   read_sheet(gs4_example("mini-gap"))
-#' }
-spread_sheet <- function(df,
-                         col_names = TRUE, col_types = NULL,
-                         na = "", trim_ws = TRUE,
-                         guess_max = min(1000, max(df$row)),
-                         .name_repair = "unique") {
-  col_spec <- standardise_col_spec(col_names, col_types)
+#' # ^^ gets same result as ...
+#' read_sheet(gs4_example("mini-gap"))
+spread_sheet <- function(
+  df,
+  col_names = TRUE,
+  col_types = NULL,
+  na = "",
+  trim_ws = TRUE,
+  guess_max = min(1000, max(df$row)),
+  .name_repair = "unique"
+) {
+  col_spec <- standardise_col_spec(col_names, col_types, call = current_env())
   check_character(na)
   check_bool(trim_ws)
   check_non_negative_integer(guess_max)
 
   spread_sheet_impl_(
     df,
-    col_spec = col_spec, na = na, trim_ws = trim_ws, guess_max = guess_max,
+    col_spec = col_spec,
+    na = na,
+    trim_ws = trim_ws,
+    guess_max = guess_max,
     .name_repair = .name_repair
   )
 }
 
-spread_sheet_impl_ <- function(df,
-                               col_spec = list(
-                                 col_names = TRUE, col_types = NULL
-                               ),
-                               na = "", trim_ws = TRUE,
-                               guess_max = min(1000, max(df$row)),
-                               .name_repair = "unique") {
+spread_sheet_impl_ <- function(
+  df,
+  col_spec = list(
+    col_names = TRUE,
+    col_types = NULL
+  ),
+  na = "",
+  trim_ws = TRUE,
+  guess_max = min(1000, max(df$row)),
+  .name_repair = "unique",
+  call = caller_env()
+) {
   if (nrow(df) == 0) {
     return(tibble::tibble())
   }
@@ -183,20 +198,25 @@ spread_sheet_impl_ <- function(df,
   ctypes <- col_spec$ctypes
   col_names_in_sheet <- isTRUE(col_names)
 
-  ## absolute spreadsheet coordinates no longer relevant
-  ## update row, col to refer to location in output data frame
-  ## row 0 holds cells designated as column names
+  # absolute spreadsheet coordinates no longer relevant
+  # update row, col to refer to location in output data frame
+  # row 0 holds cells designated as column names
   df$row <- df$row - min(df$row) + !col_names_in_sheet
   nr <- max(df$row)
   df$col <- df$col - min(df$col) + 1
 
   if (is.logical(col_names)) {
-    ## if col_names is logical, this is first chance to check/set length of
-    ## ctypes, using the cell data
-    ctypes <- rep_ctypes(max(df$col), ctypes, "columns found in sheet")
+    # if col_names is logical, this is first chance to check/set length of
+    # ctypes, using the cell data
+    ctypes <- rep_ctypes(
+      max(df$col),
+      ctypes,
+      "column{?s} found in sheet",
+      call = call
+    )
   }
 
-  ## drop cells in skipped cols, update df$col and ctypes
+  # drop cells in skipped cols, update df$col and ctypes
   skipped_col <- ctypes == "COL_SKIP"
   if (any(skipped_col)) {
     df <- df[!df$col %in% which(skipped_col), ]
@@ -205,13 +225,16 @@ spread_sheet_impl_ <- function(df,
   }
   nc <- max(df$col)
 
-  ## if column names were provided explicitly, we need to check that length
-  ## of col_names (and, therefore, ctypes) == nc
+  # if column names were provided explicitly, we need to check that length
+  # of col_names (and, therefore, ctypes) == nc
   if (is.character(col_names) && length(col_names) != nc) {
-    stop_glue(
-      "Length of {bt('col_names')} is not compatible with the data:\n",
-      "  * Expected {length(col_names)} un-skipped columns\n",
-      "  * But data has {nc} columns"
+    gs4_abort(
+      c(
+        "Length of {.arg col_names} is not compatible with the data:",
+        "*" = "{.arg col_names} has length {length(col_names)}.",
+        "x" = "But data has {nc} un-skipped column{?s}."
+      ),
+      call = call
     )
   }
 
@@ -222,7 +245,8 @@ spread_sheet_impl_ <- function(df,
   }
   if (col_names_in_sheet) {
     this <- df$row == 0
-    col_names[df$col[this]] <- as_character(df$cell[this])
+    col_names[df$col[this]] <-
+      as_character(df$cell[this], na = na, trim_ws = trim_ws)
     df <- df[!this, ]
   }
 
@@ -232,7 +256,10 @@ spread_sheet_impl_ <- function(df,
     df_split,
     ctypes,
     make_column,
-    na = na, trim_ws = trim_ws, nr = nr, guess_max = guess_max
+    na = na,
+    trim_ws = trim_ws,
+    nr = nr,
+    guess_max = guess_max
   ) %>%
     set_names(col_names) %>%
     discard(is.null)
@@ -242,36 +269,43 @@ spread_sheet_impl_ <- function(df,
 
 ## helpers ---------------------------------------------------------------------
 
-standardise_col_spec <- function(col_names, col_types) {
-  check_col_names(col_names)
-  ctypes <- standardise_ctypes(col_types)
+standardise_col_spec <- function(col_names, col_types, call = caller_env()) {
+  check_col_names(col_names, call = call)
+  ctypes <- standardise_ctypes(col_types, call = call)
   if (is.character(col_names)) {
-    ctypes <- rep_ctypes(length(col_names), ctypes, "column names")
+    ctypes <- rep_ctypes(
+      length(col_names),
+      ctypes,
+      "column name{?s}",
+      call = call
+    )
     col_names <- filter_col_names(col_names, ctypes)
-    ## if column names were provided explicitly, this is now true
-    ## length(col_names) == length(ctypes[ctypes != "COL_SKIP"])
+    # if column names were provided explicitly, this is now true
+    # length(col_names) == length(ctypes[ctypes != "COL_SKIP"])
   }
   list(col_names = col_names, ctypes = ctypes)
 }
 
-check_col_names <- function(col_names) {
+check_col_names <- function(col_names, call = caller_env()) {
   if (is.logical(col_names)) {
-    return(check_bool(col_names))
+    return(check_bool(col_names, call = call))
   }
-  check_character(col_names)
-  check_has_length(col_names)
+  check_character(col_names, call = call)
+  check_has_length(col_names, call = call)
 }
 
-## input:  a string of readr-style shortcodes or NULL
-## output: a vector of col types of length >= 1
-standardise_ctypes <- function(col_types) {
+# input:  a string of readr-style shortcodes or NULL
+# output: a vector of col types of length >= 1
+standardise_ctypes <- function(col_types, call = caller_env()) {
   col_types <- col_types %||% "?"
-  check_string(col_types)
+  check_string(col_types, call = call)
 
   if (identical(col_types, "")) {
-    stop_glue(
-      "{bt('col_types')}, if provided, must be a string that contains at ",
-      "least one readr-style shortcode."
+    gs4_abort(
+      "
+      {.arg col_types}, when provided, must be a string that contains at \\
+      least one readr-style shortcode.",
+      call = call
     )
   }
 
@@ -280,21 +314,27 @@ standardise_ctypes <- function(col_types) {
   col_types_split <- strsplit(col_types, split = "")[[1]]
   ok <- col_types_split %in% accepted_codes
   if (!all(ok)) {
-    bad_codes <- glue_collapse(sq(col_types_split[!ok]), sep = ",")
-    stop_glue(
-      "{bt('col_types')} must be a string of readr-style shortcodes:\n",
-      "  * Unrecognized codes: {bad_codes}"
+    gs4_abort(
+      c(
+        "{.arg col_types} must be a string of readr-style shortcodes. \\
+         Unrecognized code{?s}{cli::qty(sum(!ok))}:",
+        bulletize(gargle_map_cli(col_types_split[!ok]), bullet = "x")
+      ),
+      call = call
     )
   }
   ctypes <- ctype(col_types_split)
   if (all(ctypes == "COL_SKIP")) {
-    stop_glue("{bt('col_types')} can't request that all columns be skipped")
+    gs4_abort(
+      "{.arg col_types} can't request that all columns be skipped.",
+      call = call
+    )
   }
   ctypes
 }
 
-## makes sure there are n ctypes or n ctypes that are not COL_SKIP
-rep_ctypes <- function(n, ctypes, comparator = "n") {
+# makes sure there are n ctypes or n ctypes that are not COL_SKIP
+rep_ctypes <- function(n, ctypes, comparator = "n", call = caller_env()) {
   if (length(ctypes) == n) {
     return(ctypes)
   }
@@ -305,17 +345,24 @@ rep_ctypes <- function(n, ctypes, comparator = "n") {
   if (length(ctypes) == 1) {
     return(rep_len(ctypes, length.out = n))
   }
-  stop_glue(
-    "Length of {bt('col_types')} is not compatible with {comparator}:\n",
-    "  * {length(ctypes)} column types specified\n",
-    "  * {n_col_types} un-skipped column types specified\n",
-    "  * But there are {n} {comparator}."
+  # must pre-pluralize the comparator, e.g.
+  # column{?s} found in sheet
+  # column name{?s}
+  comparator <- cli::pluralize(sprintf("{cli::qty(n)}%s{?s}", comparator))
+  gs4_abort(
+    c(
+      "Length of {.arg col_types} is not compatible with {comparator}:",
+      x = "{length(ctypes)} column type{?s} specified.",
+      x = "{n_col_types} un-skipped column type{?s} specified.",
+      x = "But there {cli::qty(n)}{?is/are} {n} {comparator}."
+    ),
+    call = call
   )
 }
 
-## removes col_names for skipped columns
-## rep_ctypes() is called before and ensures that col_names and ctypes are
-## conformable (hence the non-user facing stopifnot())
+# removes col_names for skipped columns
+# rep_ctypes() is called before and ensures that col_names and ctypes are
+# conformable (hence the non-user facing stopifnot())
 filter_col_names <- function(col_names, ctypes) {
   stopifnot(length(col_names) <= length(ctypes))
   col_names[ctypes != "COL_SKIP"]
