@@ -3,13 +3,13 @@ new_range_spec <- function(...) {
   l <- list2(...)
   structure(
     list(
-      sheet_name  = l$sheet_name  %||% NULL,
+      sheet_name = l$sheet_name %||% NULL,
       named_range = l$named_range %||% NULL,
-      cell_range  = l$cell_range  %||% NULL,
+      cell_range = l$cell_range %||% NULL,
       cell_limits = l$cell_limits %||% NULL,
-      shim        = FALSE,
-      sheets_df   = l$sheets_df   %||% NULL,
-      nr_df       = l$nr_df       %||% NULL
+      shim = FALSE,
+      sheets_df = l$sheets_df %||% NULL,
+      nr_df = l$nr_df %||% NULL
     ),
     # useful when debugging range specification, but otherwise this is TMI
     # .input = l$.input,
@@ -23,12 +23,13 @@ as_range_spec <- function(x, ...) {
 
 #' @export
 as_range_spec.default <- function(x, ...) {
-  stop_glue(
-    "Can't make a range suitable for the Sheets API from the supplied ",
-    "{bt('range')}.\n",
-    "{bt('range')} must be NULL, a string, or a cell_limits object.\n",
-    "  * {bt('range')} has class {class_collapse(x)}"
-  )
+  gs4_abort(c(
+    "Can't make a range suitable for the Sheets API from the supplied \\
+     {.arg range}.",
+    x = "{.arg range} has class {.cls {class(x)}}.",
+    i = "{.arg range} must be {.code NULL}, a string, or \\
+         a {.cls cell_limits} object."
+  ))
 }
 
 ## as_range_spec.character ----
@@ -45,18 +46,23 @@ as_range_spec.default <- function(x, ...) {
 # Sheet1  A1:B2         ****
 # 3       A1:B2         ****
 #' @export
-as_range_spec.character <- function(x,
-                                    ...,
-                                    sheet = NULL,
-                                    skip = 0,
-                                    sheets_df = NULL,
-                                    nr_df = NULL) {
+as_range_spec.character <- function(
+  x,
+  ...,
+  sheet = NULL,
+  skip = 0,
+  sheets_df = NULL,
+  nr_df = NULL
+) {
   check_length_one(x)
 
   out <- new_range_spec(
-    sheets_df = sheets_df, nr_df = nr_df,
+    sheets_df = sheets_df,
+    nr_df = nr_df,
     .input = list(
-      sheet = sheet, range = x, skip = skip
+      sheet = sheet,
+      range = x,
+      skip = skip
     )
   )
 
@@ -66,7 +72,7 @@ as_range_spec.character <- function(x,
   if (notNA(m[[".match"]])) {
     out$sheet_name <- lookup_sheet_name(m$sheet, sheets_df)
     out$cell_range <- m$cell_range
-    out$shim       <- TRUE
+    out$shim <- TRUE
     return(out)
   }
 
@@ -89,11 +95,11 @@ as_range_spec.character <- function(x,
   # range must be in A1 notation
   m <- grepl(A1_rx, strsplit(x, split = ":")[[1]])
   if (!all(m)) {
-    stop_glue(
-      "{bt('range')} doesn't appear to be a range in A1 notation, a named ",
-      "range, or a sheet name:\n",
-      "  * {dq(x)}"
-    )
+    gs4_abort(c(
+      "{.arg range} doesn't appear to be a range in A1 notation, a named \\
+       range, or a sheet name:",
+      x = "{.range {x}}"
+    ))
   }
   out$cell_range <- x
   if (!is.null(sheet)) {
@@ -114,11 +120,13 @@ as_range_spec.character <- function(x,
 #             >0    Express skip request in cell_limits object and re-dispatch.
 # Sheet1 / 2  >0    <same as previous>
 #' @export
-as_range_spec.NULL <- function(x,
-                               ...,
-                               sheet = NULL,
-                               skip = 0,
-                               sheets_df = NULL) {
+as_range_spec.NULL <- function(
+  x,
+  ...,
+  sheet = NULL,
+  skip = 0,
+  sheets_df = NULL
+) {
   out <- new_range_spec(
     sheets_df = sheets_df,
     .input = list(sheet = sheet, skip = skip)
@@ -133,7 +141,8 @@ as_range_spec.NULL <- function(x,
 
   as_range_spec(
     cell_rows(c(skip + 1, NA)),
-    sheet = sheet, sheets_df = sheets_df,
+    sheet = sheet,
+    sheets_df = sheets_df,
     shim = FALSE
   )
 }
@@ -150,11 +159,13 @@ as_range_spec.NULL <- function(x,
 # Sheet1 / 2  cell_limits   Resolve sheet name, make A1 range, send combined
 #                           result.
 #' @export
-as_range_spec.cell_limits <- function(x,
-                                      ...,
-                                      shim = TRUE,
-                                      sheet = NULL,
-                                      sheets_df = NULL) {
+as_range_spec.cell_limits <- function(
+  x,
+  ...,
+  shim = TRUE,
+  sheet = NULL,
+  sheets_df = NULL
+) {
   out <- new_range_spec(
     sheets_df = sheets_df,
     .input = list(sheet = sheet, range = x, shim = shim)
@@ -176,8 +187,8 @@ format.range_spec <- function(x, ...) {
 
 #' @export
 print.range_spec <- function(x, ...) {
- cat(format(x), sep = "\n")
- invisible(x)
+  cat(format(x), sep = "\n")
+  invisible(x)
 }
 
 as_A1_range <- function(x) {
@@ -206,7 +217,7 @@ as_A1_range <- function(x) {
 #
 #   # retrieve spreadsheet metadata ----------------------------------------------
 #   x <- gs4_get(ssid)
-#   message_glue("Spreadsheet name: {dq(x$name)}")
+#   gs4_bullets(c(i = "Spreadsheet name: {.s_sheet {x$name}}"))
 #
 #   # range specification --------------------------------------------------------
 #   range_spec <- as_range_spec(
@@ -214,8 +225,7 @@ as_A1_range <- function(x) {
 #     sheets_df = x$sheets, nr_df = x$named_ranges
 #   )
 #   A1_range <- as_A1_range(range_spec)
-#   message_glue("A1 range {dq(A1_range)}")
+#   gs4_bullets(c(i = "A1 range {.range {A1_range}}"))
 #
 #   range_spec
 # }
-
