@@ -19,7 +19,7 @@
 #' seconds per user"
 #'
 #' Note that the "project" here means everyone using googlesheets4 who hasn't
-#' configured their own OAuth app. This is potentially a lot of users, all
+#' configured their own OAuth client. This is potentially a lot of users, all
 #' acting independently.
 #'
 #' If you hit the "100 requests per 100 seconds per **user**" limit (which
@@ -28,7 +28,7 @@
 #'
 #' If you experience lots of retries, especially with 100 second delays, it
 #' means your use of googlesheets4 is more than casual and **it's time for you
-#' to get your own OAuth app or use a service account token**. This is explained
+#' to get your own OAuth client or use a service account token**. This is explained
 #' in the gargle vignette `vignette("get-api-credentials", package = "gargle")`.
 #'
 #' @param x List. Holds the components for an HTTP request, presumably created
@@ -46,15 +46,24 @@
 #' @family low-level API functions
 request_make <- function(x, ..., encode = "json") {
   gargle::request_retry(
-    x, ..., encode = encode, user_agent = gs4_user_agent()
+    x,
+    ...,
+    encode = encode,
+    user_agent = gs4_user_agent()
   )
 }
 
 gs4_user_agent <- function() {
   httr::user_agent(paste0(
-    "googlesheets4/", utils::packageVersion("googlesheets4"), " ",
-    "(GPN:RStudio; )", " ",
-    "gargle/", utils::packageVersion("gargle"), " ",
-    "httr/", utils::packageVersion("httr")
+    "googlesheets4/",
+    utils::packageVersion("googlesheets4"),
+    " ",
+    "(GPN:RStudio; )",
+    " ",
+    "gargle/",
+    utils::packageVersion("gargle"),
+    " ",
+    "httr/",
+    utils::packageVersion("httr")
   ))
 }
