@@ -29,7 +29,7 @@
 #' * `sheet_write()` is the right name according to the naming convention used
 #'   throughout the googlesheets4 package.
 #'
-#' `write_sheet()` and `sheet_write()` are synonyms and you can use either one.
+#' `write_sheet()` and `sheet_write()` are equivalent and you can use either one.
 #'
 #' @param data A data frame. If it has zero rows, we send one empty pseudo-row
 #'   of data, so that we can apply the usual table styling. This empty row goes
@@ -43,45 +43,41 @@
 #' @family write functions
 #' @family worksheet functions
 #'
-#' @examples
-#' if (gs4_has_token()) {
-#'   df <- data.frame(
-#'     x = 1:3,
-#'     y = letters[1:3]
-#'   )
+#' @examplesIf gs4_has_token()
+#' df <- data.frame(
+#'   x = 1:3,
+#'   y = letters[1:3]
+#' )
 #'
-#'   # specify only a data frame, get a new Sheet, with a random name
-#'   ss <- write_sheet(df)
-#'   read_sheet(ss)
+#' # specify only a data frame, get a new Sheet, with a random name
+#' ss <- write_sheet(df)
+#' read_sheet(ss)
 #'
-#'   # clean up
-#'   googledrive::drive_trash(ss)
+#' # clean up
+#' googledrive::drive_trash(ss)
 #'
-#'   # create a Sheet with some initial, placeholder data
-#'   ss <- gs4_create(
-#'     "sheet-write-demo",
-#'     sheets = list(alpha = data.frame(x = 1), omega = data.frame(x = 1))
-#'   )
+#' # create a Sheet with some initial, placeholder data
+#' ss <- gs4_create(
+#'   "sheet-write-demo",
+#'   sheets = list(alpha = data.frame(x = 1), omega = data.frame(x = 1))
+#' )
 #'
-#'   # write df into its own, new sheet
-#'   sheet_write(df, ss = ss)
+#' # write df into its own, new sheet
+#' sheet_write(df, ss = ss)
 #'
-#'   # write mtcars into the sheet named "omega"
-#'   sheet_write(mtcars, ss = ss, sheet = "omega")
+#' # write mtcars into the sheet named "omega"
+#' sheet_write(mtcars, ss = ss, sheet = "omega")
 #'
-#'   # get an overview of the sheets
-#'   sheet_properties(ss)
+#' # get an overview of the sheets
+#' sheet_properties(ss)
 #'
-#'   # view your magnificent creation in the browser
-#'   gs4_browse(ss)
+#' # view your magnificent creation in the browser
+#' gs4_browse(ss)
 #'
-#'   # clean up
-#'   gs4_find("sheet-write-demo") %>%
-#'     googledrive::drive_trash()
-#' }
-sheet_write <- function(data,
-                        ss = NULL,
-                        sheet = NULL) {
+#' # clean up
+#' gs4_find("sheet-write-demo") %>%
+#'   googledrive::drive_trash()
+sheet_write <- function(data, ss = NULL, sheet = NULL) {
   data_quo <- enquo(data)
   data <- eval_tidy(data_quo)
   check_data_frame(data)
@@ -105,7 +101,7 @@ sheet_write <- function(data,
 
   # retrieve spreadsheet metadata ----------------------------------------------
   x <- gs4_get(ssid)
-  message_glue("Writing to {dq(x$name)}")
+  gs4_bullets(c(v = "Writing to {.s_sheet {x$name}}."))
 
   # no `sheet` ... but maybe we can name the sheet after the data --------------
   if (is.null(sheet) && quo_is_symbol(data_quo)) {
@@ -138,7 +134,7 @@ sheet_write <- function(data,
       list(bureq_clear_sheet(s$id))
     )
   }
-  message_glue("Writing to sheet {dq(s$name)}")
+  gs4_bullets(c(v = "Writing to sheet {.w_sheet {s$name}}."))
 
   # create request to write data frame into sheet ------------------------------
   requests <- c(
