@@ -7,7 +7,7 @@ test_that("range_flood() works", {
   skip_if_no_token()
 
   dat <- tibble::tibble(x = rep(1, 3), y = rep(2, 3), z = rep(3, 3))
-  ss <- scoped_temporary_ss(me_(), sheets = list(dat))
+  ss <- local_ss(me_(), sheets = list(dat))
 
   # clear values and format
   range_flood(ss, range = "A:A")
@@ -34,6 +34,12 @@ test_that("range_flood() works", {
   expect_true(all(unlist(fmts) == 1))
 
   column_C_header <- out[out$col == 3 & out$row == 1, ]
-  fmt <- purrr::pluck(column_C_header, "cell", 1, "effectiveFormat", "backgroundColor")
+  fmt <- purrr::pluck(
+    column_C_header,
+    "cell",
+    1,
+    "effectiveFormat",
+    "backgroundColor"
+  )
   expect_true(all(unlist(fmt) < 1))
 })
