@@ -3,9 +3,9 @@ me_ <- nm_fun("TEST-sheet_add")
 
 # ---- tests ----
 test_that("sheet_add() rejects non-character `sheet`", {
-  expect_error(
+  expect_snapshot(
     sheet_add(test_sheet("googlesheets4-cell-tests"), sheet = 3),
-    "must be character"
+    error = TRUE
   )
 })
 
@@ -15,29 +15,31 @@ test_that("sheet_add() works", {
 
   ss <- local_ss(me_())
 
-  expect_error_free(
+  expect_no_error(
     sheet_add(ss)
   )
 
-  expect_error_free(
+  expect_no_error(
     sheet_add(ss, "apple", .after = 1)
   )
 
-  expect_error_free(
+  expect_no_error(
     sheet_add(ss, "banana", .after = "apple")
   )
 
-  expect_error_free(
+  expect_no_error(
     sheet_add(ss, c("coconut", "dragonfruit"))
   )
 
-  expect_error_free(
+  expect_no_error(
     sheet_add(
       ss,
       sheet = "eggplant",
       .before = 1,
       gridProperties = list(
-        rowCount = 3, columnCount = 6, frozenRowCount = 1
+        rowCount = 3,
+        columnCount = 6,
+        frozenRowCount = 1
       )
     )
   )
@@ -46,7 +48,15 @@ test_that("sheet_add() works", {
 
   expect_identical(
     sheets_df$name,
-    c("eggplant", "Sheet1", "apple", "banana", "Sheet2", "coconut", "dragonfruit")
+    c(
+      "eggplant",
+      "Sheet1",
+      "apple",
+      "banana",
+      "Sheet2",
+      "coconut",
+      "dragonfruit"
+    )
   )
   expect_identical(vlookup("eggplant", sheets_df, "name", "grid_rows"), 3L)
   expect_identical(vlookup("eggplant", sheets_df, "name", "grid_columns"), 6L)
