@@ -7,12 +7,14 @@ test_that("sheet_resize() works", {
   skip_if_no_token()
 
   ss <- local_ss(me_())
+  local_gs4_loud()
 
   # no resize occurs
-  expect_message(sheet_resize(ss, nrow = 2, ncol = 6), "No need")
+  expect_message(sheet_resize(ss, nrow = 2, ncol = 6), "No need") %>%
+    suppressMessages()
 
   # reduce sheet size
-  sheet_resize(ss, nrow = 5, ncol = 7, exact = TRUE)
+  suppressMessages(sheet_resize(ss, nrow = 5, ncol = 7, exact = TRUE))
   props <- sheet_properties(ss)
   expect_equal(props$grid_rows, 5)
   expect_equal(props$grid_columns, 7)
@@ -27,7 +29,11 @@ test_that("prepare_resize_request() works for resize & no resize", {
   # 3 * 3 * 2 = 18 combinations
 
   # exact = FALSE
-  df <- expand.grid(nrow_needed = n + -1:1, ncol_needed = m + -1:1, exact = FALSE)
+  df <- expand.grid(
+    nrow_needed = n + -1:1,
+    ncol_needed = m + -1:1,
+    exact = FALSE
+  )
   req <- pmap(df, prepare_resize_request, sheet_info = sheet_info)
   grid_properties <- purrr::map(
     req,
@@ -53,7 +59,11 @@ test_that("prepare_resize_request() works for resize & no resize", {
   )
 
   # exact = TRUE
-  df <- expand.grid(nrow_needed = n + -1:1, ncol_needed = m + -1:1, exact = TRUE)
+  df <- expand.grid(
+    nrow_needed = n + -1:1,
+    ncol_needed = m + -1:1,
+    exact = TRUE
+  )
   req <- pmap(df, prepare_resize_request, sheet_info = sheet_info)
   grid_properties <- purrr::map(
     req,
